@@ -268,8 +268,8 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import cdk8s
-import constructs
+import cdk8s as _cdk8s_d3d9af27
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -291,18 +291,11 @@ class CustomResourceProvider:
         :param kind: Kind of this custom resource.
         '''
         if __debug__:
-            def stub(
-                *,
-                api_version: builtins.str,
-                handler: ICustomResourceProviderHandler,
-                kind: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__63bd57a14e8e614c52758046c35e30c05a339d75a654cc92443e130cfb5ccbdc)
             check_type(argname="argument api_version", value=api_version, expected_type=type_hints["api_version"])
             check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
             check_type(argname="argument kind", value=kind, expected_type=type_hints["kind"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "api_version": api_version,
             "handler": handler,
             "kind": kind,
@@ -351,10 +344,10 @@ class ICustomResourceProviderHandler(typing_extensions.Protocol):
     @jsii.member(jsii_name="apply")
     def apply(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         spec: typing.Any,
-    ) -> constructs.Construct:
+    ) -> _constructs_77d1e7e8.Construct:
         '''
         :param scope: -
         :param id: -
@@ -371,33 +364,31 @@ class _ICustomResourceProviderHandlerProxy:
     @jsii.member(jsii_name="apply")
     def apply(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         spec: typing.Any,
-    ) -> constructs.Construct:
+    ) -> _constructs_77d1e7e8.Construct:
         '''
         :param scope: -
         :param id: -
         :param spec: -
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                spec: typing.Any,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6ceb167d79d8aecac66e191906cc74b1ab75e0141b457629d880751a5a42735b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument spec", value=spec, expected_type=type_hints["spec"])
-        return typing.cast(constructs.Construct, jsii.invoke(self, "apply", [scope, id, spec]))
+        return typing.cast(_constructs_77d1e7e8.Construct, jsii.invoke(self, "apply", [scope, id, spec]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
 typing.cast(typing.Any, ICustomResourceProviderHandler).__jsii_proxy_class__ = lambda : _ICustomResourceProviderHandlerProxy
 
 
-class Operator(cdk8s.App, metaclass=jsii.JSIIMeta, jsii_type="cdk8s-operator.Operator"):
+class Operator(
+    _cdk8s_d3d9af27.App,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="cdk8s-operator.Operator",
+):
     '''A CDK8s app which allows implementing Kubernetes operators using CDK8s constructs.'''
 
     def __init__(
@@ -465,16 +456,10 @@ class OperatorProps:
         :param output_file: Where to write the synthesized output. Default: "/dev/stdout"
         '''
         if __debug__:
-            def stub(
-                *,
-                input_file: typing.Optional[builtins.str] = None,
-                output_file: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0a3bf04ab8b6ddadebc84ec5dd2ffb000fdee8d372c0d96b617bcbee11d50da3)
             check_type(argname="argument input_file", value=input_file, expected_type=type_hints["input_file"])
             check_type(argname="argument output_file", value=output_file, expected_type=type_hints["output_file"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if input_file is not None:
             self._values["input_file"] = input_file
         if output_file is not None:
@@ -531,9 +516,7 @@ class Server(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-operator.Server"):
         :param port: The port to listen to. If not specified, the ``PORT`` environment variable will be used. If that's not specified an available port will be auto-selected.
         '''
         if __debug__:
-            def stub(port: typing.Optional[jsii.Number] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f3d6766c69f77f090730ffbc89a6aaabaa54a16a0b1c9d42b8794041ab3db9b)
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         return typing.cast(jsii.Number, jsii.ainvoke(self, "listen", [port]))
 
@@ -549,11 +532,9 @@ class ServerProps:
         :param app_command: The command to execute in order to synthesize the CDK app.
         '''
         if __debug__:
-            def stub(*, app_command: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4f1178d58de56b9f0c47904f9ac8087bd2a728fad1032db0aeaf104b854f42d6)
             check_type(argname="argument app_command", value=app_command, expected_type=type_hints["app_command"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "app_command": app_command,
         }
 
@@ -586,3 +567,41 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__63bd57a14e8e614c52758046c35e30c05a339d75a654cc92443e130cfb5ccbdc(
+    *,
+    api_version: builtins.str,
+    handler: ICustomResourceProviderHandler,
+    kind: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6ceb167d79d8aecac66e191906cc74b1ab75e0141b457629d880751a5a42735b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    spec: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0a3bf04ab8b6ddadebc84ec5dd2ffb000fdee8d372c0d96b617bcbee11d50da3(
+    *,
+    input_file: typing.Optional[builtins.str] = None,
+    output_file: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f3d6766c69f77f090730ffbc89a6aaabaa54a16a0b1c9d42b8794041ab3db9b(
+    port: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4f1178d58de56b9f0c47904f9ac8087bd2a728fad1032db0aeaf104b854f42d6(
+    *,
+    app_command: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
